@@ -70,7 +70,7 @@ static void _struct_build_repr(StructObject *that)
 {
         GString *str;
         PyObject *items;
-        int i;
+        gint i;
 
         g_assert(that->repr == NULL);
 
@@ -110,7 +110,7 @@ static void _struct_build_repr(StructObject *that)
 /* borrows kw */
 static PyObject* _struct_new(PyObject *kw)
 {
-        PyObject* const self = PyObject_New(StructObject, (PyTypeObject*) &StructType);
+        PyObject* const self = PyObject_New(StructObject, &StructType);
         StructObject* const that = (StructObject*) self;
 
         g_assert(self != NULL && kw != NULL);
@@ -550,9 +550,9 @@ my_g_strv_length (gchar **str_array)
 static PyObject* gtop_proc_args(PyObject *self, PyObject *args)
 {
         glibtop_proc_args buf;
-        unsigned pid;
-        int argc;
-        char **argv;
+        guint pid;
+        gint argc;
+        gchar **argv;
         PyObject *t;
 
         if(!PyArg_ParseTuple(args, "I", &pid))
@@ -586,7 +586,7 @@ static inline PyObject* mountentry_to_Struct(const glibtop_mountentry *e)
 static PyObject* gtop_mountlist(PyObject *self, PyObject *args)
 {
         glibtop_mountlist buf;
-        int allfs = FALSE;
+        gint allfs = FALSE;
         glibtop_mountentry *entries;
         PyObject *t;
 
@@ -742,7 +742,7 @@ static PyObject* gtop_proclist(PyObject *self, PyObject *args)
 {
         glibtop_proclist buf;
         PyObject *list;
-        unsigned *pids;
+        guint *pids;
         guint64 which = GLIBTOP_KERN_PROC_ALL;
         guint64 arg = 0;
 
@@ -763,7 +763,7 @@ static PyObject* gtop_ppp(PyObject *self, PyObject *args)
 {
         glibtop_ppp buf;
         PyObject *d;
-        unsigned short dev;
+        gushort dev;
 
         if(!PyArg_ParseTuple(args, "H", &dev))
                 return NULL;
@@ -780,7 +780,7 @@ static PyObject* gtop_ppp(PyObject *self, PyObject *args)
 }
 
 
-static inline PyObject * get_smp_cpu(glibtop_cpu *buf, unsigned i)
+static inline PyObject * get_smp_cpu(glibtop_cpu *buf, guint i)
 {
         PyObject *d;
 
@@ -807,7 +807,7 @@ static PyObject* gtop_cpu(PyObject *self, PyObject *args)
         glibtop_cpu buf;
         PyObject *d;
         PyObject *smp;
-        unsigned i;
+        guint i;
 
         if(!PyArg_ParseTuple(args, ""))
                 return NULL;
@@ -851,7 +851,7 @@ static PyObject* gtop_proc_state(PyObject *self, PyObject *args)
 {
         glibtop_proc_state buf;
         PyObject *d;
-        unsigned pid;
+        guint pid;
 
         if(!PyArg_ParseTuple(args, "I", &pid))
                 return NULL;
@@ -878,7 +878,7 @@ static PyObject* gtop_proc_kernel(PyObject *self, PyObject *args)
 {
         glibtop_proc_kernel buf;
         PyObject *d;
-        unsigned pid;
+        guint pid;
 
         if(!PyArg_ParseTuple(args, "I", &pid))
                 return NULL;
@@ -922,7 +922,7 @@ static inline PyObject* map_entry_to_Struct(const glibtop_map_entry *e)
 static PyObject* gtop_proc_map(PyObject *self, PyObject *args)
 {
         glibtop_proc_map buf;
-        unsigned pid;
+        guint pid;
         glibtop_map_entry *entries;
         PyObject *t;
 
@@ -943,7 +943,7 @@ static PyObject* gtop_proc_mem(PyObject *self, PyObject *args)
 {
         glibtop_proc_mem buf;
         PyObject *d;
-        unsigned pid;
+        guint pid;
 
         if(!PyArg_ParseTuple(args, "I", &pid))
                 return NULL;
@@ -967,7 +967,7 @@ static PyObject* gtop_proc_segment(PyObject *self, PyObject *args)
 {
         glibtop_proc_segment buf;
         PyObject *d;
-        unsigned pid;
+        guint pid;
 
         if(!PyArg_ParseTuple(args, "I", &pid))
                 return NULL;
@@ -993,7 +993,7 @@ static PyObject* gtop_proc_signal(PyObject *self, PyObject *args)
 {
         glibtop_proc_signal buf;
         PyObject *d;
-        unsigned pid;
+        guint pid;
 
         if(!PyArg_ParseTuple(args, "I", &pid))
                 return NULL;
@@ -1011,7 +1011,7 @@ static PyObject* gtop_proc_signal(PyObject *self, PyObject *args)
 }
 
 
-static inline PyObject * get_smp_time(glibtop_proc_time *buf, unsigned i)
+static inline PyObject * get_smp_time(glibtop_proc_time *buf, guint i)
 {
         PyObject *d;
 
@@ -1028,8 +1028,8 @@ static PyObject* gtop_proc_time(PyObject *self, PyObject *args)
 {
         glibtop_proc_time buf;
         PyObject *d, *smp;
-        unsigned pid;
-        unsigned i;
+        guint pid;
+        guint i;
 
         if(!PyArg_ParseTuple(args, "I", &pid))
                 return NULL;
@@ -1069,7 +1069,7 @@ static PyObject* gtop_proc_uid(PyObject *self, PyObject *args)
 {
         glibtop_proc_uid buf;
         PyObject *d;
-        unsigned pid;
+        guint pid;
 
         if(!PyArg_ParseTuple(args, "I", &pid))
                 return NULL;
@@ -1138,7 +1138,7 @@ open_files_entry_to_Struct(const glibtop_open_files_entry *e)
 static PyObject* gtop_proc_open_files(PyObject *self, PyObject *args)
 {
         glibtop_proc_open_files buf;
-        unsigned pid;
+        guint pid;
         glibtop_open_files_entry *entries;
         PyObject *t;
 
@@ -1282,8 +1282,8 @@ initgtop(void)
 
         Py_AtExit(gtop_at_exit);
 
-        module = Py_InitModule("gtop", (PyMethodDef*) gtop_methods);
-        PyType_Ready((PyTypeObject*) &StructType);
+        module = Py_InitModule("gtop", gtop_methods);
+        PyType_Ready(&StructType);
         PyObject_SetAttrString(module, "_Struct", (PyObject*) &StructType);
 
         register_constants(module);
