@@ -2,9 +2,10 @@ from ElementWrapper import ElementWrapper
 from ControlWrapper import ControlWrapper
 from config.StateSaver import StateSaver, DefaultStateSaver
 from Scriptlet import Scriptlet
+from display.MenuItem import MenuItem
 from utils.ErrorFormatter import ErrorFormatter
 from utils import dialog
-from utils import Unit
+from layout import Unit
 import exceptions
 
 
@@ -52,6 +53,8 @@ class Script:
         self.__environment["PT"] = Unit.UNIT_PT
         self.__environment["PERCENT"] = Unit.UNIT_PERCENT
 
+        self.__environment["MenuItem"] = MenuItem
+
         self.__environment["add_timer"] = self.__script_add_timer
         self.__environment["get_config"] = self.__script_get_config
         self.__environment["get_control"] = self.__script_get_control
@@ -125,46 +128,8 @@ class Script:
     #
     def __handle_error(self):
 
-        import sys
-        import traceback
-
-        exc_type, exc_value, tb = sys.exc_info()
-
-        lineno = -1
-        if (hasattr(exc_value, "filename") and hasattr(exc_value, "lineno")):
-            # special treatment for exceptions thrown by the Python parser
-            filename = exc_value.filename
-        else:
-            # handle the usual runtime exceptions
-            tbs = traceback.extract_tb(tb)
-            # dig back until we find the place in the script where the
-            # exception occured, not the place in the core
-            while (True):
-                trace =  tbs.pop()
-                filename = trace[0]
-                lineno = trace[1]
-                if (filename.startswith("<")): break
-            del tbs
-
-        # unref the traceback to avoid circular references
-        del tb
-
-        # determine scriptlet where the error occured
-        if (filename.startswith("<")):
-            index1 = filename.find("'")
-            index2 = filename.rfind("'")
-            sid = filename[index1 + 1:index2]
-            code = self.__scriptlets[sid].script
-        else:
-            code = None
-
-        details = ErrorFormatter().format(sys.exc_info(), code, lineno)
-
-        log("=== Error in script\n" + details)
-        dialog.warning(_("Error in script"),
-                       _("An error occured while executing a script."),
-                       details)
-
+        from utils.error import Error
+        Error().handle(self.__dsp_id)
 
 
     #
@@ -188,10 +153,13 @@ class Script:
 
         if (type(interval) not in (type(1), type(1.0), type(1L))
               or interval < 0):
-            dialog.warning(_("Error in add_timer function"),
+            raise UserError(_("Error in add_timer function"),
                            _("\"%s\" isn't a valid integer value!")
                            % `interval`)
-            return
+            #dialog.warning(_("Error in add_timer function"),
+            #               _("\"%s\" isn't a valid integer value!")
+            #               % `interval`)
+            #return
 
         import gobject
         gobject.timeout_add(interval, f)
@@ -230,12 +198,16 @@ class Script:
             wrapped = ControlWrapper(ctrl)
             return wrapped
 
-        dialog.warning(_("No Control could be found for interface %s") % \
+        raise UserError(_("No Control could be found for interface %s") % \
                                                                  (interface,),
                        _("This means that a functionality won't be available "
                          "during execution!"))
+        #dialog.warning(_("No Control could be found for interface %s") % \
+        #                                                         (interface,),
+        #               _("This means that a functionality won't be available "
+        #                 "during execution!"))
 
-        return ""
+        #return ""
 
 
     #
@@ -394,7 +366,7 @@ class Script:
     #
     # Executes a block of script.
     #
-    def execute(self, scriptlet):
+    def execute(self, scriptlet, handle_error = True):
 
         sid = scriptlet.script_id
 
@@ -406,11 +378,14 @@ class Script:
 
         # compile and run
         try:
+            from utils.error import Error
+            Error().register_code("<inline '%s'>" % sid, code)
             pycode = compile(code, "<inline '%s'>" % sid, 'exec')
             #pycode = compile(code, "%s" % scriptlet.filename, 'exec')
             exec pycode in self.__environment
 
         except:
+            #if (handle_error):
             self.__handle_error()
 
 
@@ -424,7 +399,7 @@ class Script:
             return
         # TODO: if the type of the bound variable differs we have to check it
         cmd = "__retrieve__ = %s" % (name,)
-        self.execute(Scriptlet(cmd, "<internal>"))
+        self.execute(Scriptlet(cmd, "<internal>"), handle_error = False)
 
         # may raise an exception
         return self.__environment.pop("__retrieve__")
@@ -438,7 +413,7 @@ class Script:
 
         self.__environment["__inject__"] = value
         cmd = "%s = __inject__" % name
-        self.execute(Scriptlet(cmd, "<internal>"))
+        self.execute(Scriptlet(cmd, "<internal>"), handle_error = False)
         self.__environment.pop("__inject__")
 
 
@@ -448,12 +423,12 @@ class Script:
     #
     def call_function(self, name, *args):
 
-        func = self.get_value(name) #self.__environment.get(name, Null)
+        func = self.get_value(name)
         try:
             func(*args)
         except:
-            #import traceback; traceback.print_exc()
-            log("A function call in the inline script failed.")
+            #log("A function call in the inline script failed.")
+            self.__handle_error()
 
 
 
