@@ -18,7 +18,7 @@ __ALPHA36 =  string.digits + string.letters
 
 def _pretty_excepthook(mytype, value, traceb):
 
-    out = "=== Error in the core! Please report this bug!\n"
+    out = "=== Unhandled error! Something bad and unexpected happened.\n"
     out += ErrorFormatter().format(tb = (mytype, value, traceb),
                                    deep_trace = True)
     log(out)
@@ -36,7 +36,7 @@ def _log(data, is_warning = False):
     if (is_warning):
         if (data in _warnings_so_far): return
         else: _warnings_so_far[data] = 1
-    
+
 
     now = time.strftime("%D-%T", time.localtime(time.time()))
     out = "[" + now + "]==="
@@ -52,6 +52,19 @@ _warnings_so_far = {}
 __builtin__.log = _log
 
 
+def parse_color(color):
+
+    if (color[0] == "#" and len(color) == 9):
+        alpha = int(color[-2:], 16)
+        color = color[:-2]
+    else:
+        alpha = 255
+
+    import gtk
+    c = gtk.gdk.color_parse(color)
+    return (c.red >> 8, c.green >> 8, c.blue >> 8, alpha)
+
+
 def radix(n, b):
 
     """
@@ -90,7 +103,6 @@ def radix(n, b):
     return sign + rep[::-1]
 
 
-
 def makedirs(path):
 
     """Recursive directory creation function
@@ -122,12 +134,14 @@ def makedirs(path):
         return False
 
 
-def request_call(function, *args):
-
+def _request_call(when_idle, function, *args):
     """
     Runs the given function by a timer. If several calls of that function
-    occured before, only the last one is run.
+    occured before, only the last one is run. Do not call this function
+    directly, instead use one of its wrappers 'request_call' and
+    'request_idle_call'.
     """
+    assert (function != None)
 
     import gobject
 
@@ -137,12 +151,19 @@ def request_call(function, *args):
 
     tstamp = time.time()
     _timestamps[function] = tstamp
-    gobject.idle_add(f, tstamp, function, args)
+    if (when_idle):
+        gobject.idle_add(f, tstamp, function, args)
+    else:
+        gobject.timeout_add(0, f, tstamp, function, args)
 
+
+def request_call(function, *args): _request_call(False, function, *args)
+def request_idle_call(function, *args): _request_call(True, function, *args)
+
+        
 _timestamps = {}
 
 
-
 def run_in_main_thread(function, *args):
 
     """
@@ -162,6 +183,7 @@ def run_in_main_thread(function, *args):
         except Exception, exc:
             log("Warning: %s(%s) has raised an exception while running in "
                 "main thread.\nThe error was:\n%s" % (function, args, exc))
+            import traceback; traceback.print_exc()
             return
 
     else:
@@ -174,6 +196,7 @@ def run_in_main_thread(function, *args):
             except Exception, exc:
                 log("Warning: %s(%s) has raised an exception while running in "
                     "main thread.\nThe error was:\n%s" % (function, args, exc))
+
             event.set()
 
         gobject.timeout_add(0, tmout)
@@ -223,7 +246,6 @@ def run_nonblocking(function, *args):
         return ret
 
 
-
 #
 # Bind binds a function with arguments
 # e.g.  f_with_arg = Bind(f, arg)  ->  f_with_0() <-> f(arg)
