@@ -1,6 +1,12 @@
+from tiling import Tiling
+
 import gtk
 
 
+
+tiling = Tiling()
+
+
 #
 # Restricts the given coordinates to visible values.
 #
@@ -12,8 +18,8 @@ def _crop_coords(x, y, width, height):
     x = min(x, scrwidth - 1)
     y = min(y, scrheight - 1)
 
-    width = min(scrwidth - x, width)
-    height = min(scrheight - y, height)
+    #width = min(scrwidth - x, width)
+    #height = min(scrheight - y, height)
 
     return (x, y, width, height)
 
@@ -30,10 +36,12 @@ def get_wallpaper(widget, x, y, width, height):
     # get wallpaper
     try:
         pmap_id = get_wallpaper_id()
-        import tiling
-        tiling.tile_transparency(widget, pmap_id, x, y, width, height)
-    except:
-        raise NotImplementedError
+        widget.set_from_background(pmap_id, x, y, width, height)
+
+    except NotImplementedError:
+        widget.set_from_background(0, x, y, width, height)
+
+    widget.render(width, height, 1, 1)
 
 
 
@@ -49,4 +57,3 @@ def get_wallpaper_id():
 
     except:
         raise NotImplementedError
-
